==> nextcloud-31.0.3-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/updatenotification/l10n/pt_BR.js <==
OC.L10N.register(
    "updatenotification",
    {
    "Channel updated" : "Canal atualizado",
    "Web updater is disabled" : "O atualizador de Web está desativado",
    "App updated" : "Aplicativo atualizado",
    "See what's new" : "Veja o que é novo",
    "{app} updated to version {version}" : "{app} atualizado para a versão {version}",
    "Update notifications" : "Notificações de atualização",
    "The update server could not be reached since %d days to check for new updates." : "O servidor de atualização não foi encontrado já há %d dias para verificar por novas atualizações.",
    "Please check the Nextcloud and server log files for errors." : "Verifique se há erros nos arquivos de log do servidor e do Nextcloud ",
    "Update to {serverAndVersion} is available." : "Uma atualização para {serverAndVersion} está disponível.",
    "Update for {app} to version %s is available." : "Atualização para {app} para a versão %s está disponível.",
    "Update notification" : "Notificação de atualização",
    "Displays update notifications for Nextcloud, app updates, and provides the SSO for the updater." : "Exibe notificações de atualização para o Nextcloud, atualizações de aplicativos e fornece o SSO para o atualizador.",
    "Give feedback" : "Dê um retorno",
    "Get started" : "Iniciar",
    "No changelog available" : "Nenhum registro de alterações disponível",
    "What's new in {app} {version}" : "Novidades em {app} {version}",
    "A new version is available: <strong>{newVersionString}</strong>" : "Uma nova versão está disponível: <strong>{newVersionString}</strong>",
    "Note that after a new release the update only shows up after the first minor release or later. We roll out new versions spread out over time and sometimes skip a version when issues are found. Learn more about updates and release channels at {link}" : "Observe que após um novo lançamento, a atualização só aparece após o primeiro lançamento secundário ou posterior. Lançamos novas versões ao longo do tempo e, às vezes, pulamos uma versão quando são encontrados problemas. Saiba mais sobre atualizações e canais de lançamento em {link}",
    "Checked on {lastCheckedDate} - Open changelog" : "Verificado em {lastCheckedDate} - Abrir registro de alterações",
    "Checking apps for compatible versions" : "Verificando aplicativos para versões compatíveis",
    "Please make sure your config.php does not set <samp>appstoreenabled</samp> to false." : "Certifique-se de que seu config.php não tenha configurado <samp>appstoreenabled</samp> para falso.",
    "Could not connect to the App Store or no updates have been returned at all. Search manually for updates or make sure your server has access to the internet and can connect to the App Store." : "Não foi possível conectar à App Store ou nenhuma atualização foi retornada. Pesquise manualmente por atualizações ou certifique-se de que seu servidor tenha acesso à Internet e possa se conectar à App Store.",
    "<strong>All</strong> apps have a compatible version for this Nextcloud version available." : "<strong>Todos</strong> os aplicativos têm uma versão compatível para esta versão do Nextcloud disponível.",
    "_<strong>%n</strong> app has no compatible version for this Nextcloud version available._::_<strong>%n</strong> apps have no compatible version for this Nextcloud version available._" : ["<strong>%n</strong> aplicativo não têm versão compatível para esta versão do Nextcloud disponível.","<strong>%n</strong> aplicativos não têm versão compatível para esta versão do Nextcloud disponível.","<strong>%n</strong> aplicativos não têm versão compatível para esta versão do Nextcloud disponível."],
    "Enterprise" : "Empresarial",
    "For enterprise use. Provides always the latest patch level, but will not update to the next major release immediately. That update happens once Nextcloud GmbH has done additional hardening and testing for large-scale and mission-critical deployments. This channel is only available to customers and provides the Nextcloud Enterprise package." : "Para uso empresarial. Fornece sempre o nível de patch mais recente, mas não será atualizado para a próxima versão principal imediatamente. Essa atualização acontece assim que a Nextcloud GmbH fizer mais ajustes e testes para implantações de larga escala e missão crítica. Este canal está disponível apenas para clientes do Nextcloud Enterprise.",
    "Stable" : "Estável",
    "The most recent stable version. It is suited for regular use and will always update to the latest major version." : "A versão estável mais recente. É adequada para uso regular e será sempre atualizada para a versão principal mais recente.",
    "Beta" : "Beta",
    "A pre-release version only for testing new features, not for production environments." : "Uma versão de pré-lançamento para testar novos recursos, não indicada para produção.",
    "Update" : "Atualizar",
    "The version you are running is not maintained anymore. Please make sure to update to a supported version as soon as possible." : "A versão que você está executando não é mais mantida. Por favor, atualize para uma versão suportada o mais rápido possível.",
    "Apps missing compatible version" : "Aplicativos sem versão compatível ",
    "View in store" : "Ver na loja",
    "Apps with compatible version" : "Aplicativos com versão compatível ",
    "Please note that the web updater is not recommended with more than 100 accounts! Please use the command line updater instead!" : "Observe que o atualizador da web não é recomendado para mais de 100 contas! Por favor, use o atualizador de linha de comando!",
    "Open updater" : "Abrir atualizador",
    "Download now" : "Baixar agora",
    "Web updater is disabled. Please use the command line updater or the appropriate update mechanism for your installation method (e.g. Docker pull) to update." : "O atualizador da Web está desativado. Use o atualizador de linha de comando ou o mecanismo de atualização apropriado para o seu método de instalação (por exemplo, Docker pull) para atualizar.",
    "What's new?" : "O que há de novo?",
    "View changelog" : "Visualizar registro de alterações",
    "The update check is not yet finished. Please refresh the page." : "A verificação de atualização ainda não acabou. Atualize a página.",
    "Your version is up to date." : "Sua versão está atualizada.",
    "A non-default update server is in use to be checked for updates:" : "Um servidor de atualização não padrão está sendo verificado por atualizações:",
    "Update channel" : "Canal de atualização",
    "Changing the update channel also affects the apps management page. E.g. after switching to the beta channel, beta app updates will be offered to you in the apps management page." : "Alterar o canal de atualização também afeta a página de gerenciamento de aplicativos. Por exemplo. depois de mudar para o canal beta, as atualizações do aplicativo beta serão oferecidas a você na página de gerenciamento de aplicativos.",
    "Current update channel:" : "Canal de atualização atual:",
    "You can always update to a newer version. But you can never downgrade to a more stable version." : "Sempre é possível atualizar para uma versão mais nova, mas não é possível retroceder para uma versão mais antiga.",
    "Notify members of the following groups about available updates:" : "Notificar membros dos seguintes grupos sobre atualizações disponíveis:",
    "No groups" : "Nenhum grupo",
    "Only notifications for app updates are available." : "Apenas notificações para atualizações de aplicativos estão disponíveis. ",
    "The selected update channel makes dedicated notifications for the server obsolete." : "A atualização selecionada fornece notificações dedicadas para o servidor desatualizado.",
    "The selected update channel does not support updates of the server." : "A atualização selecionada não fornece suporte a atualizações do servidor.",
    "Changelog for app {app}" : "Registro de alterações do aplicativo {app}",
    "What's new in {app} version {version}" : "Novidades em {app} versão {version}",
    "{version} is available. Get more information on how to update." : "{version} está disponível. Obtenha mais informações sobre como atualizar."
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");

==> nextcloud-32.0.0-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/updatenotification/l10n/pt_BR.js <==
OC.L10N.register(
    "updatenotification",
    {
    "Channel updated" : "Canal atualizado",
    "Web updater is disabled" : "O atualizador de Web está desativado",
    "App updated" : "Aplicativo atualizado",
    "See what's new" : "Veja o que é novo",
    "{app} updated to version {version}" : "{app} atualizado para a versão {version}",
    "Update notifications" : "Notificações de atualização",
    "The update server could not be reached since %d days to check for new updates." : "O servidor de atualização não foi encontrado já há %d dias para verificar por novas atualizações.",
    "Please check the Nextcloud and server log files for errors." : "Verifique se há erros nos arquivos de log do servidor e do Nextcloud ",
    "Update to {serverAndVersion} is available." : "Uma atualização para {serverAndVersion} está disponível.",
    "Update for {app} to version %s is available." : "Atualização para {app} para a versão %s está disponível.",
    "Update notification" : "Notificação de atualização",
    "Displays update notifications for Nextcloud, app updates, and provides the SSO for the updater." : "Exibe notificações de atualização para o Nextcloud, atualizações de aplicativos e fornece o SSO para o atualizador.",
    "Give feedback" : "Dê um retorno",
    "Get started" : "Comece agora",
    "No changelog available" : "Nenhum registro de alterações disponível",
    "What's new in {app} {version}" : "Novidades em {app} {version}",
    "A new version is available: <strong>{newVersionString}</strong>" : "Uma nova versão está disponível: <strong>{newVersionString}</strong>",
    "Note that after a new release the update only shows up after the first minor release or later. We roll out new versions spread out over time and sometimes skip a version when issues are found. Learn more about updates and release channels at {link}" : "Observe que após um novo lançamento, a atualização só aparece após o primeiro lançamento secundário ou posterior. Lançamos novas versões ao longo do tempo e, às vezes, pulamos uma versão quando são encontrados problemas. Saiba mais sobre atualizações e canais de lançamento em {link}",
    "Checked on {lastCheckedDate} - Open changelog" : "Verificado em {lastCheckedDate} - Abrir registro de alterações",
    "Checking apps for compatible versions" : "Verificando aplicativos para versões compatíveis",
    "Please make sure your config.php does not set <samp>appstoreenabled</samp> to false." : "Certifique-se de que seu config.php não tenha configurado <samp>appstoreenabled</samp> para falso.",
    "Could not connect to the App Store or no updates have been returned at all. Search manually for updates or make sure your server has access to the internet and can connect to the App Store." : "Não foi possível conectar à Loja de Aplicativos ou nenhuma atualização foi retornada. Pesquise manualmente por atualizações ou certifique-se de que seu servidor tenha acesso à Internet e possa se conectar à Loja de Aplicativos.",
    "<strong>All</strong> apps have a compatible version for this {productName} version available." : "<strong>Todos</strong> os aplicativos têm uma versão compatível com esta versão {productName} disponíveis.",
    "_<strong>%n</strong> app has no compatible version for this {productName} version available._::_<strong>%n</strong> apps have no compatible version for this {productName} version available._" : ["<strong>%n</strong> aplicativo não tem uma versão compatível com esta versão {productName} disponível.","<strong>%n</strong> de aplicativos não têm uma versão compatível com esta versão {productName} disponíveis.","<strong>%n</strong> aplicativos não têm uma versão compatível com esta versão {productName} disponíveis."],
    "Enterprise" : "Empresarial",
    "For enterprise use. Provides always the latest patch level, but will not update to the next major release immediately." : "Para uso empresarial. Fornece sempre o nível de patch mais recente, mas não atualiza imediatamente para a próxima versão principal.",
    "That update happens once {vendor} has done additional hardening and testing for large-scale and mission-critical deployments." : "Essa atualização ocorre depois que {vendor} realiza reforços e testes adicionais para implantações em grande escala e de missão crítica.",
    "This channel is only available to customers and provides the {enterprise} package." : "Este canal está disponível apenas para clientes e fornece o pacote {enterprise}.",
    "Stable" : "Estável",
    "The most recent stable version. It is suited for regular use and will always update to the latest major version." : "A versão estável mais recente. É adequada para uso regular e será sempre atualizada para a versão principal mais recente.",
    "Beta" : "Beta",
    "A pre-release version only for testing new features, not for production environments." : "Uma versão de pré-lançamento para testar novos recursos, não indicada para produção.",
    "Update" : "Atualização",
    "The version you are running is not maintained anymore. Please make sure to update to a supported version as soon as possible." : "A versão que você está executando não é mais mantida. Por favor, atualize para uma versão suportada o mais rápido possível.",
    "Apps missing compatible version" : "Aplicativos sem versão compatível",
    "View in store" : "Ver na loja",
    "Apps with compatible version" : "Aplicativos com versão compatível",
    "Please note that the web updater is not recommended with more than 100 accounts! Please use the command line updater instead!" : "Observe que o atualizador da web não é recomendado para mais de 100 contas! Por favor, use o atualizador de linha de comando!",
    "Open updater" : "Abrir atualizador",
    "Download now" : "Baixar agora",
    "Web updater is disabled. Please use the command line updater or the appropriate update mechanism for your installation method (e.g. Docker pull) to update." : "O atualizador da web está desativado. Use o atualizador de linha de comando ou o mecanismo de atualização apropriado para o seu método de instalação (p. ex., Docker pull) para atualizar.",
    "What's new?" : "O que há de novo?",
    "View changelog" : "Visualizar registro de alterações",
    "The update check is not yet finished. Please refresh the page." : "A verificação de atualização ainda não acabou. Atualize a página.",
    "Your version is up to date." : "Sua versão está atualizada.",
    "A non-default update server is in use to be checked for updates:" : "Um servidor de atualização não padrão está sendo verificado por atualizações:",
    "Update channel" : "Canal de atualização",
    "Changing the update channel also affects the apps management page. E.g. after switching to the beta channel, beta app updates will be offered to you in the apps management page." : "Alterar o canal de atualização também afeta a página de gerenciamento de aplicativos. Por exemplo. depois de mudar para o canal beta, as atualizações do aplicativo beta serão oferecidas a você na página de gerenciamento de aplicativos.",
    "Current update channel:" : "Canal de atualização atual:",
    "You can always update to a newer version. But you can never downgrade to a more stable version." : "Sempre é possível atualizar para uma versão mais nova, mas não é possível retroceder para uma versão mais antiga.",
    "Notify members of the following groups about available updates:" : "Notificar membros dos seguintes grupos sobre atualizações disponíveis:",
    "No groups" : "Nenhum grupo",
    "Only notifications for app updates are available." : "Apenas notificações para atualizações de aplicativos estão disponíveis. ",
    "The selected update channel makes dedicated notifications for the server obsolete." : "A atualização selecionada fornece notificações dedicadas para o servidor desatualizado.",
    "The selected update channel does not support updates of the server." : "A atualização selecionada não fornece suporte a atualizações do servidor.",
    "Changelog for app {app}" : "Registro de alterações do aplicativo {app}",
    "What's new in {app} version {version}" : "Novidades na versão {version} do {app}",
    "{version} is available. Get more information on how to update." : "{version} está disponível. Obtenha mais informações sobre como atualizar.",
    "<strong>All</strong> apps have a compatible version for this Nextcloud version available." : "<strong>Todos</strong> os aplicativos têm uma versão compatível para esta versão do Nextcloud disponível.",
    "_<strong>%n</strong> app has no compatible version for this Nextcloud version available._::_<strong>%n</strong> apps have no compatible version for this Nextcloud version available._" : ["<strong>%n</strong> aplicativo não têm versão compatível para esta versão do Nextcloud disponível.","<strong>%n</strong> aplicativos não têm versão compatível para esta versão do Nextcloud disponível.","<strong>%n</strong> aplicativos não têm versão compatível para esta versão do Nextcloud disponível."],
    "For enterprise use. Provides always the latest patch level, but will not update to the next major release immediately. That update happens once Nextcloud GmbH has done additional hardening and testing for large-scale and mission-critical deployments. This channel is only available to customers and provides the Nextcloud Enterprise package." : "Para uso empresarial. Fornece sempre o nível de patch mais recente, mas não será atualizado para a próxima versão principal imediatamente. Essa atualização acontece assim que a Nextcloud GmbH fizer mais ajustes e testes para implantações de larga escala e missão crítica. Este canal está disponível apenas para clientes do Nextcloud Enterprise."
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
